@@ -20,6 +20,7 @@ our $Utils =
               min => \&build_min_reformatter,
               max => \&build_max_reformatter,
               hoge => sub { sub () {"hogehoge"}},
+              check_default => \&check_default,
              }
             ],
             ]
@@ -44,4 +45,11 @@ sub build_max_reformatter {
   }
 }
 
+sub check_default {
+  my ($pkg, $class, $name, $args, $default_args) = @_;
+  sub {
+    return $default_args;
+  }
+}
+
 1;
